DataComponentMap

Struct DataComponentMap 

pub struct DataComponentMap {
    pub(super) map: FxHashMap<Identifier, ComponentData>,
}
Storage for component values.

Maps component keys to their values. Used on items to store their data components.

Fields

map: FxHashMap<Identifier, ComponentData>

Implementations

Source

impl DataComponentMap

pub fn new() -> Self

pub fn common_item_components() -> Self

Creates a map with common item components pre-populated.

pub fn builder_set<T: Component + DowncastType>( self, component: DataComponentType<T>, value: Option<T>, ) -> Self

Sets a component value (builder pattern).

pub fn set<T: Component + DowncastType>( &mut self, component: DataComponentType<T>, value: Option<T>, )

Sets a component value, or removes it if None.

pub fn get<T: Component + DowncastType + Clone>( &self, component: DataComponentType<T>, ) -> Option<T>

Gets a component value by type.

pub fn get_ref<T: Component + DowncastType>( &self, component: DataComponentType<T>, ) -> Option<&T>

Gets a reference to a component value.

pub fn has<T>(&self, component: DataComponentType<T>) -> bool

Checks if a component is present.

pub fn len(&self) -> usize

Returns the number of components.

pub fn is_empty(&self) -> bool

Returns true if empty.

pub fn keys(&self) -> impl Iterator<Item = &Identifier>

Iterates over component keys.

pub fn iter(&self) -> impl Iterator<Item = (&Identifier, &ComponentData)>

Iterates over component keys and their erased values.

pub fn get_raw(&self, key: &Identifier) -> Option<&ComponentData>

Gets raw component data by key (for plugin use).

pub fn set_raw(&mut self, key: Identifier, data: ComponentData) -> bool

Sets raw component data (for plugin use).

Returns true if the data was set successfully, or false if the key is unregistered or the data type does not match it.

This prevents plugins from setting invalid types on vanilla components.

pub fn remove(&mut self, key: &Identifier) -> Option<ComponentData>

Removes a component by key.

Source

impl DataComponentMap

fn as_patch(&self) -> DataComponentPatch

pub fn try_to_nbt_tag_ref(&self) -> Result<OwnedNbtTag>

Strictly encodes this component map through its persistent codecs.

pub fn to_nbt_tag_ref(&self) -> OwnedNbtTag

Encodes this component map while reporting and omitting invalid values.